%==================================================================
%plot turbulence intensity of each profile in one series
%normally 4 profiles are chosen: 0.00, 0.40, 1.00, 2.50
%==================================================================
clear all;

yy=[0 201];%range of y (mm)or water depth
%Which experiment do you want to analysis
%set current working directory
cd('D:\H.T.Nguyen\Works\ExperimentAnalysis\data\');
dirs = dir('series*.*');
for k = 1:length(dirs)
    close all;
    cd( dirs(k).name);
 
    %offset values for u and v
    offset  = read_data('offset.txt',1,6);
    u_offset=offset(2);
    v_offset=offset(3);
    rangeV=offset(6);
    
    %nametitle = inputdlg({'Experiment information',},'Experiment information',[1],{'Series 7 (Q = 30 l/s, h_{gate} = 12.90 cm & L = 250 cm)'});
    location(1,:)='0.00';
    location(2,:)='0.40';
    location(3,:)='1.00';   
    location(4,:)='2.50';

    %turbulence intensity profiles are calculated and plotted 
    %normally 4 locations are considered:
    %'0.00','0.40','1.00','2.50'respectively is the sections with the distance
    %from the end of the contraction 0.00m, 0.40m, 1.00m and 2.50m
    for i=1:length(location)

        %calculate u_mean,v_mean,U, signma_u,signma_v,y
        files = dir([location(i,:) '*.asc']);
        for j = 1:length(files)
            data  = read_data(files(j).name,9,3);
            u(i,j,:)=(data(2,:)-u_offset)./rangeV; %m/s
            v(i,j,:)=(data(3,:)-v_offset)./rangeV;
            y(i,j)=str2num(files(j).name(6:9))*10; %cm
        end    

        %standard deviation of u and v
        for j=1:length(files)
            %u
            signma_u(i,j)=std(u(i,j,:));	%ui=u(i,j,:);
            u_mean(i,j)=mean(u(i,j,:));
            %v
            signma_v(i,j)=std(v(i,j,:));
            v_mean(i,j)=mean(v(i,j,:));
        end   
        %depth and time averaged longitudinal velocity <u_bar>h
        U(i)=mean(u_mean(i,1:length(files)));
        V(i)=mean(v_mean(i,1:length(files)));

        %--------------------------------------------------------------------------
        %define marker for each profile 
        if i==1
            marker='o';
        end
        if i==2
            marker='p';
        end
        if i==3
            marker='<';
        end
        if i==4
            marker='*';
        end
        %---------------------------------------------------------------------------
        %plot

    	%ui(i,:)=u_mean(i,1:length(files))
        hold on;
    	subplot(2,3,1); plot(u_mean(i,1:length(files))./U(i),y(i,1:length(files)),[':k' marker]); 
    	hold on;
        subplot(2,3,2);plot(signma_u(i,1:length(files))./U(i),y(i,1:length(files)),[':k' marker]);    
        hold on;
        subplot(2,3,3); plot(signma_v(i,1:length(files))./U(i),y(i,1:length(files)),[':k' marker]);    
        hold on;
        subplot(2,3,4); plot(u_mean(i,1:length(files)),y(i,1:length(files)),[':k' marker]); 
        hold on;
        subplot(2,3,5);plot(signma_u(i,1:length(files)).*100,y(i,1:length(files)),[':k' marker]);    
        hold on;
        subplot(2,3,6); plot(signma_v(i,1:length(files)).*100,y(i,1:length(files)),[':k' marker]);    
    end           

    %print the title
    figure(1);
    subplot(232); title(dirs(k).name);

    %print label
    subplot(2,3,1);
        xlabel(['$\overline u /<\overline u>_h$' ] ,'Interpreter','Latex' );
        ylabel('y (mm)');
        axis([0.5 1.5 yy]);

    subplot(2,3,2);
        xlabel('$\sigma(u)/<\overline u>_h$','Interpreter','Latex' );
        ylabel('y (mm)');
        axis([0 0.15 yy]);
            
    subplot(2,3,3);
        xlabel('$\sigma(v)/<\overline u>_h $','Interpreter','Latex' );
        ylabel('y (mm)');
        axis([0 0.15 yy]);

    subplot(2,3,4);
        xlabel(['$\overline u $' '(m/s)' ] ,'Interpreter','Latex' );
        ylabel('y (mm)');
        axis([0.0 1.0 yy]);

    subplot(2,3,5);
        xlabel('$\sigma(u)\times 100 (m/s)$','Interpreter','Latex' );
        ylabel('y (mm)');
        axis([0 2.0 yy]);
            
    subplot(2,3,6);
        xlabel('$\sigma(v)\times 100$ (m/s)','Interpreter','Latex' );
        ylabel('y (mm)');
        axis([0 2.0 yy]);
        legend({location(1,:),location(2,:),location(3,:),location(4,:)},...
        'FontName','Arial',...
        'FontSize',6,...
        'Location','NorthEast',...
        'EdgeColor',[1 1 1]);
    
    %print to *. eps file
    cd('D:\H.T.Nguyen\Works\ExperimentAnalysis\figs');
    print('-deps2','-r350',['turbulence intensity profiles in ' dirs(k).name '.eps' ])
    cd('D:\H.T.Nguyen\Works\ExperimentAnalysis\data\');
end
